* **Installation** instructions are [here](doc/INSTALL.md)
* **SSH** instructions and common use cases are [here](doc/README-SSH.md)
* **GPG** instructions and common use cases are [here](doc/README-GPG.md)
* Instructions to configure a SafeWISE-style **PIN entry** program are [here](doc/README-PINENTRY.md)